==> nextcloud-12.0.2.tgz: nextcloud/apps/systemtags/l10n/nb.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Merkelapper",
    "Update" : "Oppdater",
    "Create" : "Opprett",
    "Select tag…" : "Velg merkelapp…",
    "Tagged files" : "Merkede filer",
    "Select tags to filter by" : "Velg merkelapper å filtrere etter",
    "No tags found" : "Fant ingen merkelapper",
    "Please select tags to filter by" : "Velg merkelapper å filtrere etter",
    "No files found for the selected tags" : "Ingen filer funnet for de valgte merkelappene",
    "Added system tag %1$s" : "La til system-merkelapp %1$s",
    "Added system tag {systemtag}" : "La til system-merkelapp {systemtag}",
    "%1$s added system tag %2$s" : "%1$s  la til system-merkelapp %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la til system-merkelapp {systemtag}",
    "Removed system tag %1$s" : "Fjernet system-merkelapp %1$s",
    "Removed system tag {systemtag}" : "Fjernet system-merkelapp {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s fjernet system-merkelapp %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjernet system-merkelapp {systemtag}",
    "You created system tag %1$s" : "Du opprettet system-merkelapp %1$s",
    "You created system tag {systemtag}" : "Du opprettet system-merkelapp {systemtag}",
    "%1$s created system tag %2$s" : "%1$s opprettet system-merkelapp %2$s",
    "{actor} created system tag {systemtag}" : "{actor} opprettet system-merkelapp {systemtag}",
    "You deleted system tag %1$s" : "Du slettet system-merkelapp %1$s",
    "You deleted system tag {systemtag}" : "Du slettet system-merkelapp {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s slettet system-merkelapp %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} slettet system-merkelapp {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du oppdaterte system-merkelapp %2$s til %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du oppdaterte system-merkelapp {oldsystemtag} til {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s oppdaterte system-merkelapp %3$s til %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} oppdaterte system-merkelapp {oldsystemtag} til {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Du la til system-merkelapp %2$s til %1$s",
    "You added system tag {systemtag} to {file}" : "Du la til system-merkelapp {systemtag} til {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la til system-merkelapp %3$s til %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la til system-merkelapp {systemtag} til {file}",
    "You removed system tag %2$s from %1$s" : "Du fjernet system-merkelapp %2$s fra %1$s",
    "You removed system tag {systemtag} from {file}" : "Du fjernet system-merkelapp {systemtag} fra {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjernet system-merkelapp %3$s fra %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjernet system-merkelapp {systemtag} fra {file}",
    "%s (restricted)" : "%s (begrenset)",
    "%s (invisible)" : "%s (usynlig)",
    "<strong>System tags</strong> for a file have been modified" : "Endringer av en fils <strong>System-merkelapper</strong>",
    "Collaborative tags" : "Felles merkelapper",
    "Create and edit collaborative tags. These tags affect all users." : "Opprett og rediger samarbeidsmessige merkelapper. Disse har innvirkning på alle brukere.",
    "Select tag …" : "Velg merkelapp…",
    "Name" : "Navn",
    "Delete" : "Slett",
    "Public" : "Offentlig",
    "Restricted" : "Begrenset",
    "Invisible" : "Usynlig",
    "Reset" : "Tilbakestill",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Size" : "Størrelse",
    "Modified" : "Endret"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/systemtags/l10n/nb.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Merkelapper",
    "Update" : "Oppdater",
    "Create" : "Opprett",
    "Select tag…" : "Velg merkelapp…",
    "Tagged files" : "Filer med merkelapper",
    "Select tags to filter by" : "Velg merkelapper å filtrere etter",
    "No tags found" : "Fant ingen merkelapper",
    "Please select tags to filter by" : "Velg merkelapper å filtrere etter",
    "No files found for the selected tags" : "Ingen filer funnet for de valgte merkelappene",
    "Added system tag %1$s" : "La til system-merkelapp %1$s",
    "Added system tag {systemtag}" : "La til system-merkelapp {systemtag}",
    "%1$s added system tag %2$s" : "%1$s  la til system-merkelapp %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la til system-merkelapp {systemtag}",
    "Removed system tag %1$s" : "Fjernet system-merkelapp %1$s",
    "Removed system tag {systemtag}" : "Fjernet system-merkelapp {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s fjernet system-merkelapp %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjernet system-merkelapp {systemtag}",
    "You created system tag %1$s" : "Du opprettet system-merkelapp %1$s",
    "You created system tag {systemtag}" : "Du opprettet system-merkelapp {systemtag}",
    "%1$s created system tag %2$s" : "%1$s opprettet system-merkelapp %2$s",
    "{actor} created system tag {systemtag}" : "{actor} opprettet system-merkelapp {systemtag}",
    "You deleted system tag %1$s" : "Du slettet system-merkelapp %1$s",
    "You deleted system tag {systemtag}" : "Du slettet system-merkelapp {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s slettet system-merkelapp %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} slettet system-merkelapp {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du oppdaterte system-merkelapp %2$s til %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du oppdaterte system-merkelapp {oldsystemtag} til {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s oppdaterte system-merkelapp %3$s til %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} oppdaterte system-merkelapp {oldsystemtag} til {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Du la til system-merkelapp %2$s til %1$s",
    "You added system tag {systemtag} to {file}" : "Du la til system-merkelapp {systemtag} til {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la til system-merkelapp %3$s til %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la til system-merkelapp {systemtag} til {file}",
    "You removed system tag %2$s from %1$s" : "Du fjernet system-merkelapp %2$s fra %1$s",
    "You removed system tag {systemtag} from {file}" : "Du fjernet system-merkelapp {systemtag} fra {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjernet system-merkelapp %3$s fra %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjernet system-merkelapp {systemtag} fra {file}",
    "%s (restricted)" : "%s (begrenset)",
    "%s (invisible)" : "%s (usynlig)",
    "<strong>System tags</strong> for a file have been modified" : "Endringer av en fils <strong>System-merkelapper</strong>",
    "Collaborative tags" : "Samarbeidsmerkelapper",
    "Create and edit collaborative tags. These tags affect all users." : "Opprett og rediger samarbeidsmerkelapper. Disse har innvirkning på alle brukere.",
    "Select tag …" : "Velg merkelapp…",
    "Name" : "Navn",
    "Delete" : "Slett",
    "Public" : "Offentlig",
    "Restricted" : "Begrenset",
    "Invisible" : "Usynlig",
    "Reset" : "Tilbakestill",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Size" : "Størrelse",
    "Modified" : "Endret"
},
"nplurals=2; plural=(n != 1);");
